- .data
A SpatVector.
- ...
<tidy-select> Columns to nest; these will
appear in the inner data frames.
Specified using name-variable pairs of the form
new_col = c(col1, col2, col3). The right hand side can be any valid
tidyselect expression.
If not supplied, then ... is derived as all columns not selected by
.by, and will use the column name from .key.
:
previously you could write df |> nest(x, y, z).
Convert to df |> nest(data = c(x, y, z)).
- .by
<tidy-select> Columns to nest by; these
will remain in the outer data frame.
.by can be used in place of or in conjunction with columns supplied
through ....
If not supplied, then .by is derived as all columns not selected by
....
- .key
The name of the resulting nested column. Only applicable when
... isn't specified, i.e. in the case of df |> nest(.by = x).
If NULL, then "data" will be used by default.
- .names_sep
If NULL, the default, the inner names will come from
the former outer names. If a string, the new inner names will use the
outer names with names_sep automatically stripped. This makes
names_sep roughly symmetric between nesting and unnesting.