If x and y are not from the same data source,
and copy is TRUE, then y will be copied into the
same src as x. This allows you to join tables across srcs, but
it is a potentially expensive operation so you must opt into it.
suffix
If there are non-joined duplicate variables in x and
y, these suffixes will be added to the output to disambiguate them.
Should be a character vector of length 2.
Methods
Implementation of the genericdplyr::cross_join() method for
SpatVector objects.
The geometry column has sticky behavior. The result repeats each geometry in
x once for every row in y.
If y has a column named geometry, it is treated as a regular attribute
and receives the suffix from suffix.
See Also
dplyr::cross_join().
Other dplyr verbs that operate on pairs of SpatVector and data frame objects:
bind_cols.SpatVector,
bind_rows.SpatVector,
filter-joins.SpatVector,
mutate-joins.SpatVector,
nest_join.SpatVector(),
rows.SpatVector