powered by
SpatVector
The easiest way to create a grouped SpatVector is to call the group_by() method on a SpatVector: this will take care of capturing the unevaluated expressions for you. See group_by.SpatVector() for details.
group_by()
group_by.SpatVector()
This function is an adapted version of dplyr::is_grouped_df().
dplyr::is_grouped_df()
See also group_data.SpatVector() for the accessory functions that retrieve various metadata from a grouped SpatVector.
group_data.SpatVector()
is_grouped_spatvector(x)
TRUE if x is a grouped SpatVector, otherwise FALSE.
TRUE
x
FALSE
A SpatVector created with terra::vect().
terra::vect()
v <- terra::vect(system.file("extdata/cyl.gpkg", package = "tidyterra")) is_grouped_spatvector(v) grouped <- group_by(v, iso2) is_grouped_spatvector(grouped)
Run the code above in your browser using DataLab