A named list of values, with one value for each
layer/attribute that has missing values to be replaced. Each value in
replace will be cast to the type of the column in data where it is
used as a replacement.
...
Additional arguments for methods. Currently unused.